package main

import (
	"encoding/xml"

	"github.com/beego/beego/v2/server/web"
)

// 定义 Controller
type RespController struct {
	web.Controller
}

func (c *RespController) Get() {
	c.Ctx.WriteString("c.Ctx.WriteString")
	c.Ctx.WriteString("\n")

	c.Ctx.Output.Body([]byte("c.Ctx.Output.Body"))
	c.Ctx.WriteString("\n")

	// 返回 json 数据
	// 方式一
	m := map[string]interface{}{"a": 1, "b": 2}
	c.Ctx.Output.JSON(m, true, true)
	c.Ctx.WriteString("\n")

	// 方式二
	c.Data["json"] = m
	c.ServeJSON()

	// 返回 yaml 数据
	c.Ctx.Output.YAML(m)
	c.Data["yaml"] = m
	c.ServeYAML()

	// 返回 xml 数据
	//x := struct {
	//	XMLName xml.Name
	//	Name    string `xml:"name"`
	//	Age     int    `xml:"age"`
	//}{XMLName: xml.Name{Space: "xiexianbin.cn", Local: "root"}, Name: "xianbin", Age: 18}
	x := struct {
		XMLName xml.Name `xml:"root"`
		Name    string   `xml:"name"`
		Age     int      `xml:"age"`
	}{Name: "xianbin", Age: 18}
	c.Ctx.Output.XML(x, true)

	c.Data["xml"] = x
	c.ServeXML()

	// 返回 html 模板
	//c.TplName = "xxx.html"  // 在 views 目录下

	// 重定向
	//c.Redirect("https://www.xiexianbin.cn", 302)

	// 停止执行
	//c.StopRun()

	// 抛出错误
	//c.Abort("404")
}

func (c *RespController) Post() {
	c.Ctx.WriteString("")
}

func main() {
	web.Router("/response/", &RespController{})

	web.Run()
}
